@@ -86,7 +86,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -121,6 +121,12 @@
 #else
 #  define KCODECS_DEPRECATED_VERSION_5_56(text)
 #endif
+
+#if KCODECS_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KCODECS_DEPRECATED_VERSION_5_101(text) KCODECS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCODECS_DEPRECATED_VERSION_5_101(text)
+#endif
 #define KCODECS_DEPRECATED_VERSION_5(minor, text)      KCODECS_DEPRECATED_VERSION_5_##minor(text)
 #define KCODECS_DEPRECATED_VERSION(major, minor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCODECS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -186,7 +192,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -196,7 +202,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -221,6 +227,12 @@
 #else
 #  define KCODECS_DEPRECATED_VERSION_5_56(text)
 #endif
+
+#if KCODECS_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KCODECS_DEPRECATED_VERSION_5_101(text) KCODECS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCODECS_DEPRECATED_VERSION_5_101(text)
+#endif
 #define KCODECS_DEPRECATED_VERSION_5(minor, text)      KCODECS_DEPRECATED_VERSION_5_##minor(text)
 #define KCODECS_DEPRECATED_VERSION(major, minor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCODECS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
